summaryrefslogtreecommitdiffstats
path: root/krita/sdk/kis_shared_ptr_vector.h
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-06-25 05:28:35 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-06-25 05:28:35 +0000
commitf008adb5a77e094eaf6abf3fc0f36958e66896a5 (patch)
tree8e9244c4d4957c36be81e15b566b4aa5ea26c982 /krita/sdk/kis_shared_ptr_vector.h
parent1210f27b660efb7b37ff43ec68763e85a403471f (diff)
downloadkoffice-f008adb5a77e094eaf6abf3fc0f36958e66896a5.tar.gz
koffice-f008adb5a77e094eaf6abf3fc0f36958e66896a5.zip
TQt4 port koffice
This should enable compilation under both Qt3 and Qt4; fixes for any missed components will be forthcoming git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/applications/koffice@1238284 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'krita/sdk/kis_shared_ptr_vector.h')
-rw-r--r--krita/sdk/kis_shared_ptr_vector.h12
1 files changed, 6 insertions, 6 deletions
diff --git a/krita/sdk/kis_shared_ptr_vector.h b/krita/sdk/kis_shared_ptr_vector.h
index 0a7695a1..679bdd9f 100644
--- a/krita/sdk/kis_shared_ptr_vector.h
+++ b/krita/sdk/kis_shared_ptr_vector.h
@@ -19,21 +19,21 @@
#ifndef KIS_SHARED_PTR_VECTOR_H
#define KIS_SHARED_PTR_VECTOR_H
-#include <qvaluevector.h>
+#include <tqvaluevector.h>
#include <ksharedptr.h>
/**
* QValueVector does not always destroy an element when it is erased.
* If the items it is holding are KSharedPtr, this can result in hidden
* references to objects that cannot be accounted for. This class
* sets the KSharedPtr to 0 on erase, which dereferences the object as
* expected.
*/
template <class T>
-class KisSharedPtrVector : public QValueVector< KSharedPtr<T> >
+class KisSharedPtrVector : public TQValueVector< KSharedPtr<T> >
{
- typedef QValueVector< KSharedPtr<T> > super;
+ typedef TQValueVector< KSharedPtr<T> > super;
public:
KisSharedPtrVector() {}
@@ -53,11 +53,11 @@ public:
typename super::iterator erase(typename super::iterator first, typename super::iterator last)
{
- qFill(first, last, 0);
+ tqFill(first, last, 0);
return super::erase(first, last);
}
- bool contains(KSharedPtr<T> ptr) const
+ bool tqcontains(KSharedPtr<T> ptr) const
{
for (int i = 0, n = super::count(); i < n; ++i)
if (super::at(i) == ptr)
@@ -19,21 +19,21 @@
#include <ksharedptr.h>
/**
- * QValueVector does not always destroy an element when it is erased.
+ * TQValueVector does not always destroy an element when it is erased.
* If the items it is holding are KSharedPtr, this can result in hidden
* references to objects that cannot be accounted for. This class